@@ -61,59 +61,62 @@
 /* The capabilities are computed automatically in
  * compute_supported_archive_types() so it's correct to initialize to 0 here. */
 FrMimeTypeDescription mime_type_desc[] = {
-	{ "application/epub+zip",               ".epub",     0 },
-	{ "application/x-7z-compressed",        ".7z",       0 },
-	{ "application/x-7z-compressed-tar",    ".tar.7z",   0 },
-	{ "application/x-ace",                  ".ace",      0 },
-	{ "application/x-alz",                  ".alz",      0 },
-	{ "application/x-ar",                   ".ar",       0 },
-	{ "application/x-arj",                  ".arj",      0 },
-	{ "application/x-bzip",                 ".bz2",      0 },
-	{ "application/x-bzip-compressed-tar",  ".tar.bz2",  0 },
-	{ "application/x-bzip1",                ".bz",       0 },
-	{ "application/x-bzip1-compressed-tar", ".tar.bz",   0 },
-	{ "application/vnd.ms-cab-compressed",  ".cab",      0 },
-	{ "application/x-cbr",                  ".cbr",      0 },
-	{ "application/x-cbz",                  ".cbz",      0 },
-	{ "application/x-cd-image",             ".iso",      0 },
-	{ "application/x-chrome-extension",	".crx",      0 },
-	{ "application/x-compress",             ".Z",        0 },
-	{ "application/x-compressed-tar",       ".tar.gz",   0 },
-	{ "application/x-cpio",                 ".cpio",     0 },
-	{ "application/x-deb",                  ".deb",      0 },
-	{ "application/x-debian-package",	".deb",      0 },
-	{ "application/vnd.debian.binary-package",	".deb",      0 },
-	{ "application/vnd.snap",		".snap",     0 },
-	{ "application/vnd.squashfs",		".sqsh",     0 },
-	{ "application/x-ear",                  ".ear",      0 },
-	{ "application/x-ms-dos-executable",    ".exe",      0 },
-	{ "application/x-gzip",                 ".gz",       0 },
-	{ "application/x-java-archive",         ".jar",      0 },
-	{ "application/x-lha",                  ".lzh",      0 },
-	{ "application/x-lrzip",                ".lrz",      0 },
-	{ "application/x-lrzip-compressed-tar", ".tar.lrz",  0 },
-	{ "application/x-lz4",                  ".lz4",      0 },
-	{ "application/x-lz4-compressed-tar",   ".tar.lz4",  0 },
-	{ "application/x-lzip",                 ".lz",       0 },
-	{ "application/x-lzip-compressed-tar",  ".tar.lz",   0 },
-	{ "application/x-lzma",                 ".lzma",     0 },
-	{ "application/x-lzma-compressed-tar",  ".tar.lzma", 0 },
-	{ "application/x-lzop",                 ".lzo",      0 },
-	{ "application/x-lzop-compressed-tar",  ".tar.lzo",  0 },
-	{ "application/x-ms-wim",               ".wim",      0 },
-	{ "application/x-rar",                  ".rar",      0 },
-	{ "application/x-rpm",                  ".rpm",      0 },
-	{ "application/x-rzip",                 ".rz",       0 },
-	{ "application/x-rzip-compressed-tar",  ".tar.rz",   0 },
-	{ "application/x-tar",                  ".tar",      0 },
-	{ "application/x-tarz",                 ".tar.Z",    0 },
-	{ "application/x-stuffit",              ".sit",      0 },
-	{ "application/x-war",                  ".war",      0 },
-	{ "application/x-xar",                  ".xar",      0 },
-	{ "application/x-xz",                   ".xz",       0 },
-	{ "application/x-xz-compressed-tar",    ".tar.xz",   0 },
-	{ "application/x-zoo",                  ".zoo",      0 },
-	{ "application/zip",                    ".zip",      0 },
+	{ "application/epub+zip",                  ".epub",     0 },
+	{ "application/x-7z-compressed",           ".7z",       0 },
+	{ "application/x-7z-compressed-tar",       ".tar.7z",   0 },
+	{ "application/x-ace",                     ".ace",      0 },
+	{ "application/x-alz",                     ".alz",      0 },
+	{ "application/vnd.android.package-archive", ".apk", 0 },
+	{ "application/x-ar",                      ".ar",       0 },
+	{ "application/x-arj",                     ".arj",      0 },
+	{ "application/x-brotli",                  ".br",       0 },
+	{ "application/x-brotli-compressed-tar",   ".tar.br",   0 },
+	{ "application/x-bzip",                    ".bz2",      0 },
+	{ "application/x-bzip-compressed-tar",     ".tar.bz2",  0 },
+	{ "application/x-bzip1",                   ".bz",       0 },
+	{ "application/x-bzip1-compressed-tar",    ".tar.bz",   0 },
+	{ "application/vnd.ms-cab-compressed",     ".cab",      0 },
+	{ "application/x-cbr",                     ".cbr",      0 },
+	{ "application/x-cbz",                     ".cbz",      0 },
+	{ "application/x-cd-image",                ".iso",      0 },
+	{ "application/x-chrome-extension",        ".crx",      0 },
+	{ "application/x-compress",                ".Z",        0 },
+	{ "application/x-compressed-tar",          ".tar.gz",   0 },
+	{ "application/x-cpio",                    ".cpio",     0 },
+	{ "application/x-deb",                     ".deb",      0 },
+	{ "application/x-debian-package",          ".deb",      0 },
+	{ "application/vnd.debian.binary-package", ".deb",      0 },
+	{ "application/vnd.snap",                  ".snap",     0 },
+	{ "application/vnd.squashfs",              ".sqsh",     0 },
+	{ "application/x-ear",                     ".ear",      0 },
+	{ "application/x-ms-dos-executable",       ".exe",      0 },
+	{ "application/x-gzip",                    ".gz",       0 },
+	{ "application/x-java-archive",            ".jar",      0 },
+	{ "application/x-lha",                     ".lzh",      0 },
+	{ "application/x-lrzip",                   ".lrz",      0 },
+	{ "application/x-lrzip-compressed-tar",    ".tar.lrz",  0 },
+	{ "application/x-lz4",                     ".lz4",      0 },
+	{ "application/x-lz4-compressed-tar",      ".tar.lz4",  0 },
+	{ "application/x-lzip",                    ".lz",       0 },
+	{ "application/x-lzip-compressed-tar",     ".tar.lz",   0 },
+	{ "application/x-lzma",                    ".lzma",     0 },
+	{ "application/x-lzma-compressed-tar",     ".tar.lzma", 0 },
+	{ "application/x-lzop",                    ".lzo",      0 },
+	{ "application/x-lzop-compressed-tar",     ".tar.lzo",  0 },
+	{ "application/x-ms-wim",                  ".wim",      0 },
+	{ "application/x-rar",                     ".rar",      0 },
+	{ "application/x-rpm",                     ".rpm",      0 },
+	{ "application/x-rzip",                    ".rz",       0 },
+	{ "application/x-rzip-compressed-tar",     ".tar.rz",   0 },
+	{ "application/x-tar",                     ".tar",      0 },
+	{ "application/x-tarz",                    ".tar.Z",    0 },
+	{ "application/x-stuffit",                 ".sit",      0 },
+	{ "application/x-war",                     ".war",      0 },
+	{ "application/x-xar",                     ".xar",      0 },
+	{ "application/x-xz",                      ".xz",       0 },
+	{ "application/x-xz-compressed-tar",       ".tar.xz",   0 },
+	{ "application/x-zoo",                     ".zoo",      0 },
+	{ "application/zip",                       ".zip",      0 },
 	{ NULL, NULL, 0 }
 };
 
@@ -121,9 +124,11 @@ FrExtensionType file_ext_type[] = {
 	{ ".7z", "application/x-7z-compressed" },
 	{ ".ace", "application/x-ace" },
 	{ ".alz", "application/x-alz" },
+	{ ".apk", "application/vnd.android.package-archive" },
 	{ ".ar", "application/x-ar" },
 	{ ".arj", "application/x-arj" },
 	{ ".bin", "application/x-stuffit" },
+	{ ".br", "application/x-brotli" },
 	{ ".bz", "application/x-bzip" },
 	{ ".bz2", "application/x-bzip" },
 	{ ".cab", "application/vnd.ms-cab-compressed" },
@@ -154,6 +159,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".sqsh", "application/vnd.squashfs" },
 	{ ".swm", "application/x-ms-wim" },
 	{ ".tar", "application/x-tar" },
+	{ ".tar.br", "application/x-brotli-compressed-tar" },
 	{ ".tar.bz", "application/x-bzip-compressed-tar" },
 	{ ".tar.bz2", "application/x-bzip-compressed-tar" },
 	{ ".tar.gz", "application/x-compressed-tar" },
